==> beast-payment-api-1.3.3-20201218.092013-6-sources.jar: com/thebeastshop/payment/dto/wxcard/PWxCardMemberCardTemplateOpenDTO.java <==
package com.thebeastshop.payment.dto.wxcard;

import com.alibaba.fastjson.annotation.JSONField;
import com.thebeastshop.common.BaseDO;
import com.thebeastshop.payment.vo.wxcard.PWxCardBrand;
import com.thebeastshop.payment.vo.wxcard.PWxCardDateInformation;

public class PWxCardMemberCardTemplateOpenDTO extends BaseDO {

    @JSONField(name = "app_id")
    private String appId;

    @JSONField(name = "logo_url")
    private String logoUrl;

    @JSONField(name = "brand")
    private PWxCardBrand brand;

    @JSONField(name = "title")
    private String title;

    @JSONField(name = "background_picture_url")
    private String backgroundPictureUrl;

    @JSONField(name = "description")
    private String description;

    @JSONField(name = "service_phone")
    private String servicePhone;

    @JSONField(name = "code_type")
    private String codeType = "QRCODE";

    @JSONField(name = "date_information")
    private PWxCardDateInformation dateInformation;

    @JSONField(name = "code_mode")
    private String codeMode = "SYSTEM_ALLOCATE";

    @JSONField(name = "out_request_no")
    private String outRequestNo;

    public String getAppId() {
        return appId;
    }

    public void setAppId(String appId) {
        this.appId = appId;
    }

    public String getLogoUrl() {
        return logoUrl;
    }

    public void setLogoUrl(String logoUrl) {
        this.logoUrl = logoUrl;
    }

    public PWxCardBrand getBrand() {
        return brand;
    }

    public void setBrand(PWxCardBrand brand) {
        this.brand = brand;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public String getBackgroundPictureUrl() {
        return backgroundPictureUrl;
    }

    public void setBackgroundPictureUrl(String backgroundPictureUrl) {
        this.backgroundPictureUrl = backgroundPictureUrl;
    }

    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    public String getServicePhone() {
        return servicePhone;
    }

    public void setServicePhone(String servicePhone) {
        this.servicePhone = servicePhone;
    }

    public String getCodeType() {
        return codeType;
    }

    public void setCodeType(String codeType) {
        this.codeType = codeType;
    }

    public PWxCardDateInformation getDateInformation() {
        return dateInformation;
    }

    public void setDateInformation(PWxCardDateInformation dateInformation) {
        this.dateInformation = dateInformation;
    }

    public String getCodeMode() {
        return codeMode;
    }

    public void setCodeMode(String codeMode) {
        this.codeMode = codeMode;
    }

    public String getOutRequestNo() {
        return outRequestNo;
    }

    public void setOutRequestNo(String outRequestNo) {
        this.outRequestNo = outRequestNo;
    }
}

==> beast-payment-api-1.3.3-20201221.075714-14-sources.jar: com/thebeastshop/payment/dto/wxcard/PWxCardMemberCardTemplateOpenDTO.java <==
package com.thebeastshop.payment.dto.wxcard;

import com.alibaba.fastjson.annotation.JSONField;
import com.thebeastshop.common.BaseDO;
import com.thebeastshop.payment.vo.wxcard.PWxCardBrand;
import com.thebeastshop.payment.vo.wxcard.PWxCardDateInformation;

public class PWxCardMemberCardTemplateOpenDTO extends BaseDO {

    @JSONField(name = "appid")
    private String appId;

    @JSONField(name = "logo_url")
    private String logoUrl;

    @JSONField(name = "brand")
    private PWxCardBrand brand = new PWxCardBrand();

    @JSONField(name = "title")
    private String title;

    @JSONField(name = "background_picture_url")
    private String backgroundPictureUrl;

    @JSONField(name = "description")
    private String description;

    @JSONField(name = "service_phone")
    private String servicePhone;

    @JSONField(name = "code_type")
    private String codeType = "QRCODE";

    @JSONField(name = "date_information")
    private PWxCardDateInformation dateInformation;

    @JSONField(name = "code_mode")
    private String codeMode = "SYSTEM_ALLOCATE";

    @JSONField(name = "out_request_no")
    private String outRequestNo;

    public String getAppId() {
        return appId;
    }

    public void setAppId(String appId) {
        this.appId = appId;
    }

    public String getLogoUrl() {
        return logoUrl;
    }

    public void setLogoUrl(String logoUrl) {
        this.logoUrl = logoUrl;
    }

    public PWxCardBrand getBrand() {
        return brand;
    }

    public void setBrand(PWxCardBrand brand) {
        this.brand = brand;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public String getBackgroundPictureUrl() {
        return backgroundPictureUrl;
    }

    public void setBackgroundPictureUrl(String backgroundPictureUrl) {
        this.backgroundPictureUrl = backgroundPictureUrl;
    }

    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    public String getServicePhone() {
        return servicePhone;
    }

    public void setServicePhone(String servicePhone) {
        this.servicePhone = servicePhone;
    }

    public String getCodeType() {
        return codeType;
    }

    public void setCodeType(String codeType) {
        this.codeType = codeType;
    }

    public PWxCardDateInformation getDateInformation() {
        return dateInformation;
    }

    public void setDateInformation(PWxCardDateInformation dateInformation) {
        this.dateInformation = dateInformation;
    }

    public String getCodeMode() {
        return codeMode;
    }

    public void setCodeMode(String codeMode) {
        this.codeMode = codeMode;
    }

    public String getOutRequestNo() {
        return outRequestNo;
    }

    public void setOutRequestNo(String outRequestNo) {
        this.outRequestNo = outRequestNo;
    }
}
